/** 
 *  @file   FrameQBufMgr.xs
 *
 *  @brief      xs file
 *
 *
 *  ============================================================================
 *
 *  Copyright (c) 2008-2009, Texas Instruments Incorporated
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  
 *  *  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  
 *  *  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *  
 *  *  Neither the name of Texas Instruments Incorporated nor the names of
 *     its contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *  
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 *  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 *  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 *  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 *  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 *  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  Contact information for paper mail:
 *  Texas Instruments
 *  Post Office Box 655303
 *  Dallas, Texas 75265
 *  Contact information: 
 *  http://www-k.ext.ti.com/sc/technical-support/product-information-centers.htm?
 *  DCMP=TIHomeTracking&HQS=Other+OT+home_d_contact
 *  ============================================================================
 *  
 */




/*
 *  ======== FrameQBufMgr.xs ========
 *
 */

var ListMP = null;
var FrameQBufMgrd;
var NameServer = null ;
var GateSwi    = null;
var instCount = 0;  /* use to determine if processing last instance */

/*
 *  ======== module$use ========
 */
function module$use()
{
    var FrameQBufMgr = this;
    xdc.useModule("xdc.runtime.Startup") ;
    NameServer = xdc.useModule("ti.sdo.utils.NameServer");
    GateSwi    = xdc.useModule("ti.sysbios.gates.GateSwi");
    /*
     *  Plug in GatePeterson if the proxy is not set.
     */
    if (!FrameQBufMgr.GateProxy) {
        FrameQBufMgr.GateProxy = xdc.useModule('xdc.runtime.GateNull');
    }

}

function module$static$init(mod, params)
{
   FrameQBufMgr = this;
   /*TODO: update the module state elementes based on params */
    mod.refCount    = 0 ;
   /* Update  with the params name server handle */
    mod.nameServer       = null;
    mod.nameServerType   = 0;
    mod.gate             = null;
    mod.gateType         = 0;
    mod.cfg.eventNo =  FrameQBufMgr.NOTIFY_RESERVED_EVENTNO;
    mod.cfg.useNameServer = true;
    mod.cfg.maxInstances = FrameQBufMgr.MAXINSTANCES;

    /* Initialize the instanece no array   such that all the entries are invalid
     * at start up.
     */
    mod.isInstNoValid.length = FrameQBufMgr.MAXINSTANCES;
    for( var i = 0; i < mod.isInstNoValid.length; i++) {
        mod.isInstNoValid[i]= false;
    }

    /* Create Name server for this instance */
    if (params.useNameServer == true) {
        /* initialize the NameServer param to be used now or later */
        FrameQBufMgr.nameSrvPrms.maxRuntimeEntries = params.maxRuntimeEntries;
        FrameQBufMgr.nameSrvPrms.tableSection      = params.tableSection;
        FrameQBufMgr.nameSrvPrms.maxNameLen        = params.MAX_NAMELEN;
        FrameQBufMgr.nameSrvPrms.checkExisting     = true;
        FrameQBufMgr.nameSrvPrms.maxValueLen       =
                                         FrameQBufMgr.NameServerEntry.$sizeof();

        /*
         *  Get the current number of created static instances of this module.
         *  Note: if user creates a static instance after this point and
         *        expects to use NameServer, this is a problem.
         */
        var instCount = this.$instances.length;

        /* create NameServer here only if no static instances are created */
        if (instCount == 0) {
            mod.nameServer = NameServer.create("FrameQBufMgr",
                                                FrameQBufMgr.nameSrvPrms);
            /* set flag indicating name server is statically created */
            mod.nameServerType = FrameQBufMgr.STATIC_CREATE;
        }
        else {
            mod.nameServer = null;
        }
    }
    else {
        mod.nameServer = null;
    }

    /* Gate for module wide usage. */

    /* TODO: need to check how to  do upcasting Gate Swi handle to
     * IGateProvider.
     */
    mod.gate = GateSwi.create();

    if(mod.gate != null) {
        mod.gateType  = FrameQBufMgr.STATIC_CREATE;
    }
}

/*
 *  ======== instance$static$init ========
 *  Initializes a statically created FrameQBufMgrd object.
 */
function instance$static$init(obj, params)
{

obj.openFlag = param.openFlag ;

}


function getModuleNamserverEntrySize(NameServerEntry)
{
    /*TODO: Find out the Namserverentry structure size and return it */
    return(12);
}